/*
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */


#ifndef __TASKMANAGER_APPUI_H__
#define __TASKMANAGER_APPUI_H__

// INCLUDE FILES
#include "TaskManagerConnInfo.h"

#include <aknappui.h>

// FORWARD DECLARATIONS
class CTaskManagerAppView;
class CTaskManagerEngine;

// CLASS DECLARATION

/**
* Application UI class.
* Provides support for the following features:
* - EIKON control architecture
* 
*/
class CTaskManagerAppUi : public CAknAppUi
	{
public: // Constructors and destructor

    /**
    * Symbian OS default constructor.
    */      
	void ConstructL();

    /**
    * Destructor.
    */      
	~CTaskManagerAppUi();
	
public: // New functions

	/**
	* Returns reference to engine, which handles transactions.
	* @return Reference to engine.
	*/
	CTaskManagerEngine& Model();
	
	/**
	* Shows proper cba buttons according to the given boolean.
	* @param aShow defines whether only a cancel button (ETrue) or options and exit buttons are shown.
	*/
	void ShowConnectingCbaL(const TBool& aShow);	
	
	/**
	* AppView can inform the AppUi that it is busy doing something (like showing a query dialog).
	* While AppView is busy, AppUi makes sure that engine won't update tasks automatically.
	* @param aBusy defines whether the view is busy or not.
	*/
	void SetViewBusyL(const TBool& aBusy);


public: // Functions from base classes

    /**
    * From CEikAppUi, takes care of command handling.
    * @param aCommand command to be handled
    */
	void HandleCommandL(TInt aCommand);
	
	/**
	* From CEikAppUi, called when application switches to or from the foreground.
	* @param aForeground ETrue to switch to the foreground. EFalse to switch from the foreground.
	*/
	void HandleForegroundEventL(TBool aForeground);
	
private: // New functions

	/**
	* Reads connection setting from a settings file.
	*/
	void InternalizeConnInfoL();
	
	/**
	* Saves connection settings to a settings file.
	*/
	void ExternalizeConnInfoL();
	
	/**
	* Sets the automatic tasks loading in engine on, if AppView and AppUi aren't busy.
	*/
	void SetAutomaticUpdateL();

private: // Data members

	CTaskManagerAppView* iAppView;
	CTaskManagerEngine* iEngine;
	TTaskManagerConnInfo iConnectionInfo;
	TFileName iSettingsFile;
	TBool iViewBusy;
	TBool iUiBusy;
    
	};


#endif // __TASKMANAGER_APPUI_H__

// End of file


