/*
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */


#ifndef TASKMANAGERCONNINFO_H
#define TASKMANAGERCONNINFO_H

// INCLUDE FILES
#include "TaskManager.hrh"

#include <e32std.h>
#include <e32def.h>
#include <s32strm.h>

// CLASS DECLARATION

/**
* A class for holding connections settings.
*
*/
class TTaskManagerConnInfo
	{
public: // Constructors

	/**
	* Constructor
	*/
	TTaskManagerConnInfo();
	
public: // Getters and setters

	void SetServerAddress( const TDesC& aAddress );
	TBufC< KMaxServerNameLength > ServerAddress() const;
	
	void SetPort( const TInt aPort );
	const TInt Port() const;
	
	void SetUsername( const TDesC& aUsername );
	TBufC< KMaxUsernameLength > Username() const;
	
	void SetPassword( const TDesC& aPassword );
	TBufC< KMaxPasswordLength > Password() const;
	
	void SetIap( const TUint32& aId);
	TUint32 Iap() const;
	
public: // New functions

	/**
	* Saves connections setting to the stream.
	* @param aStream the stream where data is written.
	*/
	void ExternalizeL(RWriteStream& aStream) const;
	
	/**
	* Reads the connections settings from the stream.
	* @param aStream the stream where the data is read from.
	*/
	void InternalizeL(RReadStream& aStream);
	
private: // Data members

    // Default port, defined in .cpp file
    static const TInt               KDefaultPort;

	// Address of the server
	TBuf< KMaxServerNameLength >    iServerAddress;
	
	// Port number
	TInt iPort;
	
	// Username
	TBuf< KMaxUsernameLength >      iUsername;
	
	// Password
	TBuf< KMaxPasswordLength >      iPassword;
	
	// Default IAP;
	TUint32 iIap;
	
	};

#endif

// End of file





